@@ -546,7 +546,7 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
         Picture *pic;
         gsize bytes_pos, mimelen, desclen;
         guchar *decoded_ustr;
-        gsize decoded_len;
+        gsize decoded_size;
 
         pic = Picture_Allocate();
 
@@ -564,34 +564,87 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
         pic->data = NULL;
 
         /* Decode picture data. */
-        decoded_ustr = g_base64_decode (string, &decoded_len);
+        decoded_ustr = g_base64_decode (string, &decoded_size);
+
+        /* Check that the comment decoded to a long enough string to hold the
+         * whole structure (8 fields of 4 bytes each). */
+        if (decoded_size < 8 * 4)
+        {
+            goto invalid_picture;
+        }
 
         /* Reading picture type. */
         pic->type = read_guint32_from_byte (decoded_ustr, 0);
         bytes_pos = 4;
 
+        /* TODO: Check that there is a maximum of 1 of each of
+         * ET_PICTURE_TYPE_FILE_ICON and ET_PICTURE_TYPE_OTHER_FILE_ICON types
+         * in the file. */
+        if (pic->type >= ET_PICTURE_TYPE_UNDEFINED)
+        {
+            goto invalid_picture;
+        }
+
         /* Reading MIME data. */
         mimelen = read_guint32_from_byte (decoded_ustr, bytes_pos);
-        bytes_pos = 8 + mimelen;
+        bytes_pos += 4;
+
+        if (mimelen > decoded_size - bytes_pos - (6 * 4))
+        {
+            goto invalid_picture;
+        }
+
+        /* Check for a valid MIME type. */
+        if (mimelen > 0)
+        {
+            const gchar *mime;
+
+            mime = (const gchar *)&decoded_ustr[bytes_pos];
+
+            /* TODO: Check for "-->" when adding linked image support. */
+            if (strncmp (mime, "image/", mimelen) != 0
+                && strncmp (mime, "image/png", mimelen) != 0
+                && strncmp (mime, "image/jpeg", mimelen) != 0)
+            {
+                gchar *mime_str;
+
+                mime_str = g_strndup (mime, mimelen);
+                g_debug ("Invalid Vorbis comment image MIME type: %s",
+                         mime_str);
+
+                g_free (mime_str);
+                goto invalid_picture;
+            }
+        }
+
+        /* Skip over the MIME type, as gdk-pixbuf does not use it. */
+        bytes_pos += mimelen;
 
         /* Reading description */
         desclen = read_guint32_from_byte (decoded_ustr, bytes_pos);
         bytes_pos += 4;
 
-        pic->description = g_malloc (desclen + 1);
-
-        for (i = 0; i < desclen; i++)
+        if (desclen > decoded_size - bytes_pos - (5 * 4))
         {
-            pic->description [i] = decoded_ustr [i + bytes_pos];
+            goto invalid_picture;
         }
 
-        pic->description [desclen] = '\0';
+        pic->description = g_strndup ((const gchar *)&decoded_ustr[bytes_pos],
+                                      desclen);
+
+        /* Skip the width, height, color depth and number-of-colors fields. */
         bytes_pos += desclen + 16;
 
         /* Reading picture size */
         pic->size = read_guint32_from_byte (decoded_ustr, bytes_pos);
         bytes_pos += 4;
 
+        if (pic->size > decoded_size - bytes_pos)
+        {
+            g_free (pic->description);
+            goto invalid_picture;
+        }
+
         /* Reading decoded picture */
         pic->data = g_malloc (pic->size);
 
@@ -600,6 +653,14 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
             pic->data [i] = decoded_ustr [i + bytes_pos];
         }
 
+        g_free (decoded_ustr);
+        continue;
+
+invalid_picture:
+        /* Mark the file as modified, so that the invalid field is removed upon
+         * saving. */
+        FileTag->saved = FALSE;
+
         g_free (decoded_ustr);
     }
 
@@ -1066,6 +1127,8 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
         vcedit_clear(state);
     }
 
+    g_object_unref (file);
+
     g_assert (error == NULL || *error == NULL);
     return TRUE;
 }
