@@ -1,12 +1,20 @@
-/* This program is licensed under the GNU Library General Public License, version 2,
- * a copy of which is included with this program (LICENCE.LGPL).
+/* EasyTAG - tag editor for audio files
+ * Copyright (C) 2014 David King <amigadave@amigadave.com>
+ * Copyright (C) 2000-2001 Michael Smith <msmith@xiph.org>
  *
- * (c) 2000-2001 Michael Smith <msmith@xiph.org>
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
  *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
- * Comment editing backend, suitable for use by nice frontend interfaces.
- *
- * last modified: $Id: vcedit.c,v 1.23 2003/09/03 07:58:05 calc Exp $
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 51
+ * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "config.h" /* For definition of ENABLE_OGG. */
@@ -66,6 +74,12 @@ static void vcedit_clear_internals(vcedit_state *state)
         vorbis_info_clear(state->vi);
         free(state->vi);
     }
+#ifdef ENABLE_SPEEX
+    if (state->si)
+    {
+        speex_header_free (state->si);
+    }
+#endif
 #ifdef ENABLE_OPUS
     if (state->oi)
     {
@@ -371,11 +385,13 @@ vcedit_open(vcedit_state *state, GFile *file, GError **error)
     else
     {
 #ifdef ENABLE_SPEEX
-        // Done after "Ogg test" to avoid to display an error message in function
-        // speex_packet_to_header when the file is not Speex.
-        state->si = malloc(sizeof(SpeexHeader));
-        if((state->si = speex_packet_to_header((char*)(&header_main)->packet,(&header_main)->bytes)))
+        /* Done after "Ogg test" to avoid to display an error message in
+         * function speex_packet_to_header() when the file is not Speex. */
+        if((state->si = speex_packet_to_header ((char*)(&header_main)->packet,
+                                                (&header_main)->bytes)))
+        {
             state->oggtype = VCEDIT_IS_SPEEX;
+        }
 #endif
 #ifdef ENABLE_OPUS
         if (state->oggtype == VCEDIT_IS_UNKNOWN)
